@@ -1012,19 +1012,23 @@ class WordToken(caching.base.CachingMixin,models.Model):
         else:
             outline = {}
 
-        if outline == {}:
+        if 'Word' not in outline:
             outline['Word'] = self.WordType.Label
+        if 'Token' not in outline:
             outline['Token'] = self.pk
+        if 'Speaker' not in outline:
             outline['Speaker'] = str(self.Dialog.Speaker)
-            if form['measure'] != 'N':
-                beg,end,vow,prevSound,follSound = self.getAcousticInfo()
+
+        if form['measure'] != 'N':
+            beg,end,vow,prevSound,follSound = self.getAcousticInfo()
+            if 'Vowel' not in outline:
                 outline['Vowel'] = self.WordType.getStressVowel()
                 outline['PrevCons'] = prevSound
                 outline['FollCons'] = follSound
-        if form['segmentalDurations']:
-            if 'VowDur' not in outline:
-                outline['VowDur'] = end-beg
-                outline['OtherDur'] = self.getDuration()- outline['VowDur']
+            if form['segmentalDurations']:
+                if 'VowDur' not in outline:
+                    outline['VowDur'] = end-beg
+                    outline['OtherDur'] = self.getDuration()- outline['VowDur']
         if form['speakingRates']:
             if 'PrevSpeakRate' not in outline:
                 outline['PrevSpeakRate'] = self.getPreviousSpeakingRate()
